Index: src/compiler/pipeline.cc |
diff --git a/src/compiler/pipeline.cc b/src/compiler/pipeline.cc |
index 10daaefc490d6354a7a0cbc43bfbd8d341ed2526..aec27c4f3c9089934de96558c912977ddcf61f43 100644 |
--- a/src/compiler/pipeline.cc |
+++ b/src/compiler/pipeline.cc |
@@ -945,8 +945,8 @@ struct EscapeAnalysisPhase { |
} |
}; |
-struct RepresentationSelectionPhase { |
- static const char* phase_name() { return "representation selection"; } |
+struct SimplifiedLoweringPhase { |
+ static const char* phase_name() { return "simplified lowering"; } |
void Run(PipelineData* data, Zone* temp_zone) { |
SimplifiedLowering lowering(data->jsgraph(), temp_zone, |
@@ -1553,11 +1553,22 @@ bool PipelineImpl::CreateGraph() { |
} |
} |
- // Select representations. This has to run w/o the Typer decorator, because |
- // we cannot compute meaningful types anyways, and the computed types might |
- // even conflict with the representation/truncation logic. |
- Run<RepresentationSelectionPhase>(); |
- RunPrintAndVerify("Representations selected", true); |
+ // Do some hacky things to prepare generic lowering. |
+ Run<GenericLoweringPrepPhase>(); |
+ |
+ data->EndPhaseKind(); |
+ |
+ return true; |
+} |
+ |
+bool PipelineImpl::OptimizeGraph(Linkage* linkage) { |
+ PipelineData* data = this->data_; |
+ |
+ // Perform simplified lowering. This has to run w/o the Typer decorator, |
+ // because we cannot compute meaningful types anyways, and the computed types |
+ // might even conflict with the representation/truncation logic. |
+ Run<SimplifiedLoweringPhase>(); |
+ RunPrintAndVerify("Simplified lowering", true); |
#ifdef DEBUG |
// From now on it is invalid to look at types on the nodes, because: |
@@ -1576,17 +1587,6 @@ bool PipelineImpl::CreateGraph() { |
RunPrintAndVerify("Untyped", true); |
#endif |
- // Do some hacky things to prepare generic lowering. |
- Run<GenericLoweringPrepPhase>(); |
- |
- data->EndPhaseKind(); |
- |
- return true; |
-} |
- |
-bool PipelineImpl::OptimizeGraph(Linkage* linkage) { |
- PipelineData* data = this->data_; |
- |
// Run generic lowering pass. |
Run<GenericLoweringPhase>(); |
RunPrintAndVerify("Generic lowering", true); |